boundary_info: Get the boundary matrix and its reduction information in...

View source: R/Persistence.R

boundary_infoR Documentation

Get the boundary matrix and its reduction information in matrix form

Description

Get the boundary matrix and its reduction information in matrix form

Usage

boundary_info(filist)

Arguments

filist

Filtration list, each element includes simplex and time.

Value

A list containing the boundary matrix, the last boundary row, and the pivot owner for persistence extraction.

Examples

points <- matrix(c(0, 1, 1, 0, 0, 0, 1, 1), ncol = 2)
filtration <- build_vr_filtration(points, eps_max=1.2)
res <- boundary_info(filtration)

SimplicialComplex documentation built on Nov. 5, 2025, 7:40 p.m.