extract_persistence_pairs: This function extracts the persistence from combining the...

View source: R/Persistence.R

extract_persistence_pairsR Documentation

This function extracts the persistence from combining the boundary matrix and its filtration

Description

This function extracts the persistence from combining the boundary matrix and its filtration

Usage

extract_persistence_pairs(filist, last_1, pivot_owner)

Arguments

filist

Filtration list, each element includes simplex and time.

last_1

The last 1 row index for each column in boundary matrix.

pivot_owner

The column index owning the pivot row.

Value

A data frame with columns: dimension, birth, and death.

Examples

points <- matrix(c(0, 1, 1, 0, 0, 0, 1, 1), ncol = 2)
filtration <- build_vr_filtration(points, eps_max=1.2)
res <- boundary_info(filtration)
pairs <- extract_persistence_pairs(filtration, res$last_1, res$pivot_owner)

SimplicialComplex documentation built on Nov. 5, 2025, 7:40 p.m.