| boundary_info | R Documentation |
Get the boundary matrix and its reduction information in matrix form
boundary_info(filist)
filist |
Filtration list, each element includes simplex and time. |
A list containing the boundary matrix, the last boundary row, and the pivot owner for persistence extraction.
points <- matrix(c(0, 1, 1, 0, 0, 0, 1, 1), ncol = 2)
filtration <- build_vr_filtration(points, eps_max=1.2)
res <- boundary_info(filtration)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.